@@ -6,14 +6,14 @@ import openpyxl
 import csv
 from pathlib import Path
 
-from ..data.DataLEDET import LEDETInputs, LEDETOptions, LEDETPlots, LEDETVariables, LEDETAuxiliary
-from ..data.DataRoxieParser import APIdata
-from ..data.DataModel import DataModel
-from ..data import DictionaryLEDET
-from ..configs.tools_defaults.ToolDefaultReader import ToolDefaultReader
-from ..builders.geometricFunctions import close_pairs_ckdtree, close_pairs_pdist
-from ..builders.SelfMutualInductanceCalculation import SelfMutualInductanceCalculation
-from ..parsers.ParserMap2d import parseRoxieMap2d
+from steam_sdk.data.DataLEDET import LEDETInputs, LEDETOptions, LEDETPlots, LEDETVariables, LEDETAuxiliary
+from steam_sdk.data.DataRoxieParser import APIdata
+from steam_sdk.data import DataModel
+from steam_sdk.data import DictionaryLEDET
+from steam_sdk.configs.tools_defaults.ToolDefaultReader import ToolDefaultReader
+from steam_sdk.builders.geometricFunctions import close_pairs_ckdtree, close_pairs_pdist
+from steam_sdk.builders.SelfMutualInductanceCalculation import SelfMutualInductanceCalculation
+from steam_sdk.parsers.ParserMap2d import parseRoxieMap2d
 
 
 class BuilderLEDET:
@@ -53,7 +53,7 @@ class BuilderLEDET:
         self.enableConductorResistanceFraction = False
 
         # Load and set the default parameter descriptions
-        self.loadDefaultVariableDescriptions(os.path.join('ledet', 'variableNamesDescriptions.xlsx'))
+        self.loadDefaultVariableDescriptions(os.path.join('LEDET', 'variableNamesDescriptions.xlsx'))
 
         if (not self.model_data or not self.roxie_data) and flag_build:
             raise Exception('Cannot build model instantly without providing DataModel and RoxieData')
