@@ -1,11 +1,14 @@
 import numpy as np
 import datetime
 import openpyxl
+import shutil
 from openpyxl.cell.cell import Cell
 from openpyxl.styles import Font
 from openpyxl.utils import get_column_letter
+from pathlib import Path
 
-from ..builders.BuilderLEDET import BuilderLEDET
+from steam_sdk.builders.BuilderLEDET import BuilderLEDET
+from steam_sdk.parsers import ParserMap2d
 
 
 class ParserLEDET:
@@ -360,23 +363,76 @@ class ParserLEDET:
             if verbose: print('sim3D_f_cooling_right is a scalar. Expanding value to all half-turns')
             self.builder_ledet.Inputs.sim3D_f_cooling_right = np.array([self.builder_ledet.Inputs.sim3D_f_cooling_right] * int(np.sum(self.builder_ledet.Inputs.nT)))
 
-    def copy_map2d(self, verbose: bool = False):
-        ''' #TODO '''
-        # rename and copy
-        # self.builder_ledet.Options.flagIron
-        # self.builder_ledet.Options.flagSelfField
-        # add suffix like LEDET-Manual like in OptionsLEDET of .yaml-file
-        pass
+    def copy_map2d(self, magnet_name, verbose: bool = False):
+        ''' rename and copy '''
 
-    def copy_modified_map2d_ribbon_cable(self, geoArr, verbose: bool = False):
+        ### new naming of file (depending on magnet properties)
+
+        if self.builder_ledet.Options.flagIron == 1:
+            pre_suffix = "_WithIron"
+        else:
+            pre_suffix = "_NoIron"
+
+        if self.builder_ledet.Options.flagSelfField == 1:
+            pre_pre_suffix = "WithSelfField"
+        else:
+            pre_pre_suffix = "NoSelfFiled"
+
+        suffix = "_All" + pre_suffix + pre_pre_suffix
+
+        # Paths
+        path_sdk = Path(__file__).parent.parent.parent
+        path_ROXIE_input = Path(path_sdk, "tests", "builders", "input", magnet_name)
+        path_magnet_output = Path(path_sdk, "tests", "builders", "output", magnet_name)
+        file_name_new = magnet_name + suffix  + "test" + ".map2d"
+
+        # Copy
+        shutil.copy2(Path(path_ROXIE_input, magnet_name + ".map2d"), Path(path_magnet_output, file_name_new))
+
+        return file_name_new
+
+    def copy_modified_map2d_ribbon_cable(self, magnet_name, geometry_ribbon_cable, verbose: bool = False):
         ''' #TODO '''
-        # call ParserMap2d.modify_map2d_ribbon_cable()
-        # self.builder_ledet.Options.flagIron
-        # self.builder_ledet.Options.flagSelfField
-        # pass values to modify...
-        # get new values from modfiy... and write correct file
-        # then rename and copy
-        pass
+
+        ### Create path of required magnet files
+        # Paths
+        path_sdk = Path(__file__).parent.parent.parent
+        path_magnet_output = Path(path_sdk, "tests", "builders", "output", magnet_name)
+        path_ROXIE_input = Path(path_sdk, "tests", "builders", "input", magnet_name)
+
+        ### naming of file (depending on magnet properties)
+
+        # if self.builder_ledet.Options.flagIron == 1:
+        #     pre_suffix = "_WithIron"
+        # else:
+        #     pre_suffix = "_NoIron"
+        #
+        # if self.builder_ledet.Options.flagSelfField == 1:
+        #     pre_pre_suffix = "_WithSelfField"
+        # else:
+        #     pre_pre_suffix = "_NoSelfField"
+
+        pre_suffix = "_WithIron"
+        pre_pre_suffix = "_WithSelfField"
+        suffix = "_All" + pre_suffix + pre_pre_suffix
+        file_name_new = magnet_name + suffix + ".map2d"
+
+        # Get name and data of (old) ROXIE file
+        file_name_ROXIE = magnet_name + ".map2d"
+        file_directory_ROXIE = Path(path_ROXIE_input, file_name_ROXIE)
+        content_ROXIE_file = open(file_directory_ROXIE, "r").read().split("\n")
+
+        # Parse to ParserMap2d
+        NewMap2d = ParserMap2d.modify_map2d_ribbon_cable(file_directory_ROXIE, geometry_ribbon_cable)
+        #
+        ParserMap2d.multiply_column_by_value(NewMap2d, 3, 1000)
+        ParserMap2d.multiply_column_by_value(NewMap2d, 4, 1000)
+        ParserMap2d.multiply_column_by_value(NewMap2d, 7, 1000000)
+        # Create .map2d file from ParserMap2d
+        ParserMap2d.create_map2d_file(NewMap2d, content_ROXIE_file[0], Path(path_magnet_output, file_name_new),
+                                      file_name_new)
+
+        return file_name_new
 
 
 ###############################################################
