@@ -7,8 +7,8 @@ import yaml
 from pydantic import BaseModel, PrivateAttr
 from typing import (Deque, Dict, FrozenSet, List, Optional, Sequence, Set, Tuple, Union, Type)
 
-from ..builders import geometricFunctions
-from ..data import DataRoxieParser as pd
+from steam_sdk.builders import geometricFunctions
+from steam_sdk.data import DataRoxieParser as pd
 
 
 def arcCenter(C, iL, oL, iR, oR, diff_radius=None):
